/**
 * Copyright (C) 2007-2013 Lawrence Murray
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * $Rev$
 * $Date$
 */
#ifndef INDII_META_HPP
#define INDII_META_HPP

#ifdef URBANLIGHTSCAPE
#define PACKAGE_NAME "Urban Lightscape"
#define PACKAGE_TARNAME "urbanlightscape"
#define PACKAGE_VERSION "1.4.0"
#define PACKAGE_DESC "For localised exposure correction and lighting adjustments."
#define PACKAGE_ADOBE_ID "425"
#endif

#ifdef TINTII
#define PACKAGE_NAME "Tintii"
#define PACKAGE_TARNAME "tintii"
#define PACKAGE_VERSION "2.10.0"
#define PACKAGE_DESC "For saturation control, especially selective colour effects."
#define PACKAGE_ADOBE_ID "421"
#endif

#endif
